@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::RJBS;
-our $VERSION = '0.092830';
+our $VERSION = '0.092970';
 
 
 # ABSTRACT: BeLike::RJBS when you build your dists
@@ -37,7 +37,7 @@ sub bundle_config {
     ],
     [ MetaJSON     => { } ],
     [ NextRelease  => { } ],
-    [ PodPurler    => { } ],
+    [ PodWeaver    => { } ],
     [ Repository   => { } ],
   );
 
@@ -53,7 +53,6 @@ no Moose;
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -62,7 +61,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 0.092830
+version 0.092970
 
 =head1 DESCRIPTION
 
@@ -72,16 +71,15 @@ This is the plugin bundle that RJBS uses.  It is equivalent to:
   bundle = @Classic
   remove = PodVersion
   remove = MetaYAML
-
   [AutoVersion]
   [MetaJSON]
   [NextRelease]
-  [PodPurler]
+  [PodWeaver]
   [Repository]
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -90,6 +88,5 @@ This software is copyright (c) 2009 by Ricardo SIGNES.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
